==> xl-react-components-0.16.62.tgz: package/app/xl-react-dip/xl-react-dip-map-string-string/xl-react-dip-map-string-string-service.js <==
import R from 'ramda';
import {SortDirection} from 'react-virtualized';

export const getModelKeys = (modelValue, pristine) => R.pipe(
    R.keys,
    pristine ? R.sortBy(R.identity) : R.identity
)(modelValue);

export const filterModel = (modelValue, modelKeys, searchToken, isEncrypted) => {
    const matchesTerm = R.pipe(
        R.toString,
        R.toLower,
        R.includes(R.toLower(searchToken)),
    );

    const searchByValue = (value) => isEncrypted ? false : matchesTerm(value);
    const filterRows = R.pickBy((value, key) => searchByValue(value) || matchesTerm(key));
    const matchedKeys = R.pipe(
        searchToken ? filterRows : R.identity,
        R.keys
    )(modelValue);

    return R.reduce((acc, key) =>
        R.includes(key, matchedKeys) ? [...acc, {key, value: modelValue[key]}] : acc, [], modelKeys);
};

export const getModelWithUpdatedKey = (model, originalKey, newKey) => R.pipe(
    R.toPairs,
    R.reduce((acc, [key, value]) => ({
        ...acc,
        [key === originalKey ? R.trim(newKey) : key]: value
    }), {})
)(model);

export const getModelKeysWithUpdatedKey = (modelKeys, originalKey, newKey) => R.reduce(
    (acc, key) => key === originalKey ? [...acc, R.trim(newKey)] : [...acc, key], [], modelKeys);

export const tableSortComparator = (current, next, desc) => {
    const comparator = R.comparator(desc ? R.gt : R.lt);
    return R.isNil(current) ? Number(desc) : comparator(current, next);
};

export const comparatorBuilder = (getSortValue, desc) =>
    (object1, object2) => tableSortComparator(getSortValue(object1), getSortValue(object2), desc);

export const sortTableData = (data, sortBy, sortDirection) => {
    if (R.isNil(sortBy) || R.isNil(sortDirection)) {
        return R.identity(data);
    }

    const comparator = comparatorBuilder(
        R.pipe(
            R.prop(sortBy),
            R.cond([
                [R.isNil, R.identity],
                [R.T, String]
            ])
        ),
        sortDirection === SortDirection.DESC
    );
    return R.sort(comparator, data);
};

==> xl-react-components-0.21.15.tgz: package/app/xl-react-dip/xl-react-dip-map-string-string/xl-react-dip-map-string-string-service.js <==
import R from 'ramda';
import {SortDirection} from 'react-virtualized';

export const getModelKeys = (modelValue, pristine) => R.pipe(
    R.keys,
    pristine ? R.sortBy(R.identity) : R.identity
)(modelValue);

export const filterModel = (modelValue, modelKeys, searchToken, isEncrypted) => {
    const matchesTerm = R.pipe(
        R.toString,
        R.toLower,
        R.includes(R.toLower(searchToken))
    );

    const searchByValue = (value) => isEncrypted ? false : matchesTerm(value);
    const filterRows = R.pickBy((value, key) => searchByValue(value) || matchesTerm(key));
    const matchedKeys = R.pipe(
        searchToken ? filterRows : R.identity,
        R.keys
    )(modelValue);

    return R.reduce((acc, key) =>
        R.includes(key, matchedKeys) ? [...acc, {key, value: modelValue[key]}] : acc, [], modelKeys);
};

export const getModelWithUpdatedKey = (model, originalKey, newKey) => R.pipe(
    R.toPairs,
    R.reduce((acc, [key, value]) => ({
        ...acc,
        [key === originalKey ? R.trim(newKey) : key]: value
    }), {})
)(model);

export const getModelKeysWithUpdatedKey = (modelKeys, originalKey, newKey) => R.reduce(
    (acc, key) => key === originalKey ? [...acc, R.trim(newKey)] : [...acc, key], [], modelKeys);

export const tableSortComparator = (current, next, desc) => {
    const comparator = R.comparator(desc ? R.gt : R.lt);
    return R.isNil(current) ? Number(desc) : comparator(current, next);
};

export const comparatorBuilder = (getSortValue, desc) =>
    (object1, object2) => tableSortComparator(getSortValue(object1), getSortValue(object2), desc);

export const sortTableData = (data, sortBy, sortDirection) => {
    if (R.isNil(sortBy) || R.isNil(sortDirection)) {
        return R.identity(data);
    }

    const comparator = comparatorBuilder(
        R.pipe(
            R.prop(sortBy),
            R.cond([
                [R.isNil, R.identity],
                [R.T, String]
            ])
        ),
        sortDirection === SortDirection.DESC
    );
    return R.sort(comparator, data);
};
